@@ -29,6 +29,9 @@ sub run
 
     my $argv = sub
     {
+        delete $ENV{MYDanExtractFile};
+        delete $ENV{MYDanExtractFileAim};
+
         my $code = File::Spec->join( $this->{agent}{argv}, shift );
         return -f $code && ( $code = do $code ) && ref $code eq 'CODE'
             ? &$code( @_ ) : \@_;
